import pymongo

class MongoData():
  def __init__(self, _host="mongodb01.51yomo.com", _port=27017, _user="cryptouser", _password="cryptouser", _dbName="cryptonews"):
    #self.mongoClient = pymongo.MongoClient("mongodb://cryptouser:cryptouser@127.0.0.1:27017/?authSource=cryptonews")
    self.mongoClient = pymongo.MongoClient(f"mongodb://{_user}:{_password}@{_host}:{_port}/?authSource={_dbName}")
    self.mongodb = self.mongoClient[_dbName]

  def appendData2Array(self, _collection,  _condition, _tag, _data):
    __collection = self.mongodb[_collection]
    if __collection.find(_condition).count() == 0:
        __collection.insert_one(_condition)
    __collection.update_one(_condition, {"$push": {_tag: _data}})

if __name__ == "__main__":
  __mongo = MongoData()
  __mongo.appendData2Array("BNBUTCD", {"date" : "20210221"}, "sma05", {"timestamp": 123456, "price": 1000}    )
  __mongo.appendData2Array("BNBUTCD", {"date" : "20210222"}, "sma05", {"timestamp": 123456, "price": 1000}    )

#{date: "20210221", sma05: [{timestamp: 1234567, price: 100}, {timestamp: 123458, price: 102}], sma10: [], sma20: [], boll20: [timestamp: 12345, data: [100, 105, 106]], boll40: 23456, data: [102, 103, 104], marketPrice: [{timestamp: 12345, price: 102}]}




import psycopg2
import psycopg2.extras
from psycopg2.extras import Json
import json
import pandas.io.sql as sqlio


class PGBase():
    def __init__(self, _dbName, _user, _host, _pass):
        try:
            self.dbconn = psycopg2.connect(f"dbname='{_dbName}' user='{_user}' host='{_host}' password='{_pass}'")
        except psycopg2.Error as e:
            print("---- Failed to connect to the database")
            print(f"The error message is {e}")

    def queryData(self, _query):
        try:
            __cursor = self.dbconn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
            __cursor.execute(_query)
            #return json.dumps(__cursor.fetchall())
            return __cursor.fetchall()
        except Exception as e:
            print(f"Failed to run query {e}")
            return None

    def executeQuery(self, _query):
        try:
            __cursor = self.dbconn.cursor()
            __cursor.execute(_query)
        except Exception as e:
            print(f"Failed to run query {e}")
            return None

    def fetchDataFrame(self, _query):
        try:
            return sqlio.read_sql_query(_query, self.dbconn)
        except Exception as e:
            print(f"Failed to run query {e}")
            return None

    def fetchiDataJson(self, _query):
        try:
            __cursor = self.dbconn.cursor(cursor_factory=psycopg2.extras.DictCursor)
            __cursor.execute(_query)
            return __cursor.fetchall()
        except Exception as e:
            print(f"Failed to run query {e}")
            return None

    def commit(self):
        self.dbconn.commit()

if __name__ == "__main__":
    __dbBase = PGBase("cryptodb", "cryptouser", "192.168.1.166", "cryptouser")
    __ret = __dbBase.queryData("select to_char(current_timestamp, 'YYYY-MM-DD') as test")
    print(f"The retrn datais {__ret}")



import json
import urllib.parse
import urllib.request

class wechat():
    def __init_(self, _url):
        self.url = _url

    def sendMsg(self, _msg, _debugMode=False):
       data = { 'data': f"{_msg}" }
       data = json.dumps(data)
       data = str(data)
       data = data.encode('utf-8')
       if _debugMode == True:
           print(f"WEVHAT MSG: {data}")
       else:
           req =  urllib.request.Request(self.url, data=data)
           req.add_header('Content-Type', 'application/json')
           resp = urllib.request.urlopen(req, timeout=300)



from distutils.core import setup
setup(
  name = 'yomo-py-common',
  packages = ['yomoPyCommon', 'yomoPyCommon/db', 'yomoPyCommon/message'],
  include_package_data=True,
  version = '0.0.8',
  license='MIT',
  description = 'Define some common function for easy use',
  author = 'Chunhua Zhang',
  author_email = 'syunka.tyo@gmail.com',
  url = 'https://github.com/luyomo/yomo-py-common',
  download_url = 'https://github.com/luyomo/yomo-py-common/archive/refs/tags/0.0.8.tar.gz',
  keywords = ['postgres', 'wechat'] ,
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
